@@ -17,21 +17,14 @@
 
 from __future__ import annotations
 
-from collections.abc import Sequence
-from typing import TYPE_CHECKING, Callable, ClassVar
-
-from airflow.providers.standard.version_compat import AIRFLOW_V_3_0_PLUS
-
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.sdk.bases.decorator import get_unique_task_id, task_decorator_factory
-else:
-    from airflow.decorators.base import get_unique_task_id, task_decorator_factory  # type: ignore[no-redef]
-
+from collections.abc import Callable, Sequence
+from typing import TYPE_CHECKING, ClassVar
 
+from airflow.providers.common.compat.sdk import get_unique_task_id, task_decorator_factory
 from airflow.providers.standard.sensors.python import PythonSensor
 
 if TYPE_CHECKING:
-    from airflow.sdk.bases.decorator import TaskDecorator
+    from airflow.providers.common.compat.sdk import TaskDecorator
 
 
 class DecoratedSensorOperator(PythonSensor):
